aboutsummaryrefslogtreecommitdiffstats
path: root/Game
diff options
context:
space:
mode:
authormota23 <mota23@b956fd51-792f-4845-bead-9b4dfca2ff2c>2007-05-17 14:04:07 +0000
committermota23 <mota23@b956fd51-792f-4845-bead-9b4dfca2ff2c>2007-05-17 14:04:07 +0000
commitd52cb874cd39eac4a4aff100c22bf3280eea4275 (patch)
tree93f0c607bddc76b96c0b01f5e6d3c1e789725d63 /Game
parent6c70187a80c2d1096231957cf86410d5786254b2 (diff)
downloadusdx-d52cb874cd39eac4a4aff100c22bf3280eea4275.tar.gz
usdx-d52cb874cd39eac4a4aff100c22bf3280eea4275.tar.xz
usdx-d52cb874cd39eac4a4aff100c22bf3280eea4275.zip
added: Video Icon. Shows if Video is present in Song-Selection. Needs to be fixed.
git-svn-id: svn://svn.code.sf.net/p/ultrastardx/svn/trunk@212 b956fd51-792f-4845-bead-9b4dfca2ff2c
Diffstat (limited to 'Game')
-rw-r--r--Game/Code/Classes/UThemes.pas12
-rw-r--r--Game/Code/Screens/UScreenSong.pas11
2 files changed, 22 insertions, 1 deletions
diff --git a/Game/Code/Screens/UScreenSong.pas b/Game/Code/Screens/UScreenSong.pas
index 6f3bbc63..4fe679f7 100644
--- a/Game/Code/Screens/UScreenSong.pas
+++ b/Game/Code/Screens/UScreenSong.pas
@@ -13,6 +13,9 @@ type
TextTitle: integer;
TextNumber: integer;
+ //Video Icon Mod
+ VideoIcon: Cardinal;
+
TextCat: integer;
StaticCat: integer;
@@ -58,6 +61,7 @@ type
StaticNonParty: Array of Cardinal;
TextNonParty: Array of Cardinal;
+
constructor Create; override;
procedure SetScroll;
procedure SetScroll1;
@@ -1326,6 +1330,13 @@ begin
inherited Draw;
+ //Draw Video Icon if Video is present
+ if CatSongs.Song[Interaction].Video <> '' then
+ Static[VideoIcon].Visible := True
+ else
+ Static[VideoIcon].Visible := False;
+
+
//Draw Equalizer
if Theme.Song.Equalizer.Visible then
DrawEqualizer;
diff --git a/Game/Code/Classes/UThemes.pas b/Game/Code/Classes/UThemes.pas
index 0fe207e9..471e46bf 100644
--- a/Game/Code/Classes/UThemes.pas
+++ b/Game/Code/Classes/UThemes.pas
@@ -249,7 +249,10 @@ type
TextTitle: TThemeText;
TextNumber: TThemeText;
- //Show Cat in TopLeft Mod
+ //Video Icon Mod
+ VideoIcon: TThemeStatic;
+
+ //Show Cat in TopLeft Mod
TextCat: TThemeText;
StaticCat: TThemeStatic;
@@ -280,6 +283,7 @@ type
ColR, ColG, ColB: Real;
end;
+
//Party and Non Party specific Statics and Texts
StaticParty: AThemeStatic;
TextParty: AThemeText;
@@ -303,6 +307,8 @@ type
StaticTeam3Joker3: TThemeStatic;
StaticTeam3Joker4: TThemeStatic;
StaticTeam3Joker5: TThemeStatic;
+
+
end;
TThemeSing = class(TThemeBasic)
@@ -959,6 +965,9 @@ begin
ThemeLoadText(Song.TextTitle, 'SongTextTitle');
ThemeLoadText(Song.TextNumber, 'SongTextNumber');
+ //Video Icon Mod
+ ThemeLoadStatic(Song.VideoIcon, 'SongVideoIcon');
+
//Show Cat in TopLeft Mod
ThemeLoadStatic(Song.StaticCat, 'SongStaticCat');
ThemeLoadText(Song.TextCat, 'SongTextCat');
@@ -1020,6 +1029,7 @@ begin
ThemeLoadStatic(Song.StaticTeam3Joker4, 'SongStaticTeam3Joker4');
ThemeLoadStatic(Song.StaticTeam3Joker5, 'SongStaticTeam3Joker5');
+
// Sing
ThemeLoadBasic(Sing, 'Sing');